Backend Reference
=========================

The backend services provide calls to the external hamlet components including the hamlet java engine

Engine Management
-------------------

Manages the installation and versioning of hamlet engines

Engine
_______

 .. automodule:: hamlet.backend.engine.engine
    :members:

Engine Part
____________

.. automodule:: hamlet.backend.engine.engine_part
    :members:

Engine Source
______________

.. automodule:: hamlet.backend.engine.engine_source
    :members:

Engine Store
______________

.. automodule:: hamlet.backend.engine
    :members:

Engine Loader
________________

.. automodule:: hamlet.backend.engine.engine_loader
    :members:

Exceptions
____________

.. automodule:: hamlet.backend.engine.exceptions
    :members:
